## Required Packages

+ dmenu -- the menu
+ lolcat -- colors terminal output
+ sshpass -- for SSH connections
+ freerdp -- for RDP connections
+ expect -- a tool for automating applications

### VPN packages for Arch Linux

+ pptp
+ networkmanager
+ network-manager-applet
+ vpnc
+ networkmanager-vpnc
+ openvpn
+ networkmanager-openvpn
+ openconnect
+ network-manager-openconnect

### VPN packages for Debian

+ network-manager
+ network-manager-gnome
+ openconnect
+ network-manager-openconnect
+ network-manager-openconnect-gnome
+ openvpn
+ network-manager-openvpn
+ network-manager-openvpn-gnome
+ pptp-linux
+ network-manager-pptp
+ network-manager-pptp-gnome
+ vpnc
+ network-manager-vpnc
+ network-manager-vpnc-gnome

## How This Script Works

$EDITOR $TERMINAL and $BROWSER variables should be set in ~/.bashrc or ~/.profile

This script will scan any file located in **$Docs** and produce a menu of networks and devices to interact with.

Every time the script is run it will rewrite the ~/.bashrc.networks file.

If .bashrc.networks is sourced in your .bashrc file, this will make every network document filename a bash alias. Typing any of these aliases into a terminal window will open the network document for editing.

## The Menu

Use the arrow keys to navigate the menu, or you can type any characters to filter the menu choices. Press **Enter** to make a selection.

+ Info -- opens the network document in $EDITOR
+ Servers -- produces a menu of devices listed in the *## SERVERS* table of the network document
+ NetworkingDevices -- menu of devices listed in the *## SWITCHING & ROUTING* table of the network document
+ Workstations -- menu of devices listed in the *## WORKSTATIONS* table of the document
+ Printers -- menu of devices listed in the *## PRINTERS* table of the document
+ Ping -- menu of ALL devices listed in ALL tables of the document to send a PING command to
+ PullRC -- menu of all Cisco devices listed in the *## SWITCHING & ROUTING* table to pull a running config from
+ Reboot -- menu of ALL devices listed in ALL tables of the document to send a REBOOT command to
+ ShoVer -- menu of all Cisco devices listed in the *## SWITCHING & ROUTING* table to send a *sho ver* command to
+ VPN -- makes a VPN connection to the selected network

## The Network Document

Everything between the *three dash lines* at the top is the header. The only part of the header the script **does not** care about is who the editor of the script is. Not even sure yet why I have that line there. Anyway...

+ **title:** should be the full name of the company/organization.
+ **short-name:** is the name presented in the dmenu, and output filename prefixes.
+ **internal-domain:** is used to pass credentials for RDP sessions, and for local */etc/hosts* file edits and lookups. SSH connections are name-based - rather than IP - to avoid IP address conflicts in the .ssh/known_hosts file.
+ **vpn-type:** supported values here are **IPSec** (for **vpnc** profiles), **PPTP** (for **ppp** profiles) and **NetworkManager**.
+ **vpn-profile:**
  + for **IPSec** you should have a profile saved in /etc/vpnc -- use that name here.
  + for **PPTP** you should have a profile saved in /etc/ppp/peers -- use that name here.
  + for **NetworkManager** you should have a profile saved in /etc/NetworkManager/system-connections -- use the UUID here.\*

>\* If you need help finding the UUID, you can type this command in a terminal: **nmcli con sho**.

### The *VPN* table

Currently, this table is not used by the script; it's just here for the humans. Some day I'd like the script to be capable of reading this table to build a VPN profile if/when needed. It wouldn't even be hard to add that...

### The tables that matter

+ SWITCHING & ROUTING: document your firewalls, routers, switches, access points, etc.
+ SERVERS: should be self-explanatory, no?
+ WORKSTATIONS: RDP connections only, not terribly useful unless you use static IPs or have gotten autistic with your DHCP reservations.
+ PRINTERS: these can be other miscellaneous devices that don't fall into the other groups.

**The NAME column** should be the hostname of the computer/device. This column - being the *first word(argument)* in each line - needs to be filled with a unique hostname. If you put *SERVER* here as your hostname, and begin another line anywhere else in this document with the word *SERVER*, the connection to this device will fail.

Computer and device names from this column are produced in the dmenu when this script is executed.

**The IP column** is the (LAN) IP address that will be added/used for the FQDN lookup. Depending on your firewall management access policy, you may want to put the WAN IP of your firewall(s) here, rather than LAN IP.

**The ACCESS column** tells the script what type of connection you make to manage the computer/device. If you use more than one type to access a device, you can put the device in the table more than once, but adjust your *NAME* column accordingly.

### Example

NAME          | IP           | ACCESS | USERNAME      | PASSWORD
------------- | ------------ | ------ | ------------- | --------
SERVER01-HTTP | 192.168.0.10 | HTTP   | administrator | password
SERVER01-SSH  | 192.168.0.10 | SSH    | root          | password

### Supported Connection Types

ACCESS   | DESCRIPTION
-------- | -----------
SSH      | SSH
SSH:port | SSH on other ports
CISCOSSH | SSH for Cisco devices
RDP      | Remote Desktop
HTTP     | HTTP Website
HTTPS    | HTTPS Website
ECP      | Exchange Control Panel (Web)
