---
title: Vim Help
---

Use the **CAPSLOCK** or **ESC** keys to leave Insert mode in Vim.

## How do I quit Vim??!!

this key | does this
-------- | ---------
:w       | write changes to file
:wq      | save and close file
:q!      | quit without saving

Some keybinds use the <**leader**> key, which is bound to **SPACEBAR**.

this key  | does this
--------- | ---------
<leader>r | redraws the buffer (clears search highlights)
<leader>f | enables Goyo for prettier reading
<leader>v | runs spellcheck
<leader>c | compiles the document
<leader>p | opens the corresponding pdf/html

You can compile and open markdown documents with **F5**.

## Some common useful Vim keys

this key | does this
-------- | ---------
h        | move left
j        | move down
k        | move up
l        | move right
gg       | go to first line
G        | go to last line
:n       | go to line n
0        | (zero) start of line
^        | first non-blank character of line
$        | end of line
w        | jump by start of words (punctuation considered words)
W        | jump by words (spaces separate words)
e        | jump to end of words (punctuation considered words)
E        | jump to end of words (no punctuation)
b        | jump backward by words (punctuation considered words)
B        | jump backward by words (no punctuation)
ge       | jump backward to end of words
-        | move line upwards, on the first non blank character
+        | move line downwards, on the first non blank character
<enter>  | move line downwards, on the first non blank character
)        | move the cursor forward to the next sentence.
(        | move the cursor backward by a sentence.
{        | move the cursor a paragraph backwards
}        | move the cursor a paragraph forwards
]]       | move the cursor a section forwards or to the next {
[[       | move the cursor a section backwards or the previous {
CTRL-f   | move the cursor forward by a screen of text
CTRL-b   | move the cursor backward by a screen of text
CTRL-u   | move the cursor up by half a screen
CTRL-d   | move the cursor down by half a screen
H        | move the cursor to the top of the screen.
M        | move the cursor to the middle of the screen.
L        | move the cursor to the bottom of the screen.
fx       | search line forward for 'x'
Fx       | search line backward for 'x'
tx       | search line forward before 'x'
Tx       | search line backward before 'x'

### Insert mode

this key | does this
-------- | ---------
i        | start insert mode at cursor
I        | insert at the beginning of the line
a        | append after the cursor
A        | append at the end of the line
o        | open (append) blank line below current line
O        | open blank line above current line
Esc      | exit insert mode

### Editing

this key  | does this
--------- | ---------
r         | replace a single character (does not use insert mode)
R         | enter Insert mode, replacing characters rather than inserting
J         | join line below to the current one
cc        | change (replace) an entire line
cw        | change (replace) to the end of word
c$        | change (replace) to the end of line
s         | delete character at cursor and substitute text
S         | delete line at cursor and substitute text (same as cc)
xp        | transpose two letters (delete and paste, technically)
u         | undo
CTRL-r    | redo
.         | repeat last command
~         | switch case
g~iw      | switch case of current word
gUiw      | make current word uppercase
guiw      | make current word lowercase
gU$       | make uppercase until end of line
gu$       | make lowercase until end of line
>>        | indent line one column to right
<<        | indent line one column to left
==        | auto-indent current line
ddp       | swap current line with next
ddkp      | swap current line with previous
:%retab   | fix spaces / tabs issues in whole file
:r [name] | insert the file [name] below the cursor.
:r !{cmd} | execute {cmd} and insert its standard output below the cursor.

## Video Tutorials

From [Luke Smith's Youtube Channel](https://www.youtube.com/channel/UC2eYFnH61tmytImy1mTYvhA)

+ [Learn Vim: Exiting, Movement, Insert Mode, Basic Editing](https://www.youtube.com/watch?v=qsWY-8n9igM&t=471s)
+ [Learn Vim: Deletion, Text Objects, Motions, Undo & Redo](https://www.youtube.com/watch?v=fOedfTOToJY)
+ [After Vimtutor: Some Basic Vim Editing Tips!](https://www.youtube.com/watch?v=jUfw7aHD_xY)
+ [How Vim Makes my Daily Life Easier](https://www.youtube.com/watch?v=NzD2UdQl5Gc&t=11s)
+ [Why Vim Doesn't Need the Mouse](https://www.youtube.com/watch?v=tQCRVkSFFEc)
+ [A Vid in which Vim Saves me Hours & Hundreds of Clicks](https://www.youtube.com/watch?v=hraHAZ1-RaM)
+ [Vim Macros: Why and How-To!](https://www.youtube.com/watch?v=wRFEBw02aT8)
+ [My Dank Vim & LaTeX Setup](https://www.youtube.com/watch?v=Mphdtdv2_xs&list=PL-p5XmQHB_JSTaEPygu1DZjuFfb704Uv7&index=7)
+ [Start Turning Vim Into a Comfy IDE](https://www.youtube.com/watch?v=Q4I_Ft-VLAg&index=6&list=PL-p5XmQHB_JSTaEPygu1DZjuFfb704Uv7)
